/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2001-2002 CodeFactory AB
 * Copyright (C) 2001-2002 Richard Hult <rhult@codefactory.se>
 * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __MRP_CALENDAR_H__
#define __MRP_CALENDAR_H__

#include <glib-object.h>
#include <time.h>

#include <mrproject/mrp-object.h>
#include <mrproject/mrp-types.h>
#include <mrproject/mrp-interval.h>
#include <mrproject/mrp-time.h>

#define MRP_TYPE_CALENDAR		(mrp_calendar_get_type ())
#define MRP_CALENDAR(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), MRP_TYPE_CALENDAR, MrpCalendar))
#define MRP_CALENDAR_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), MRP_TYPE_CALENDAR, MrpCalendarClass))
#define MRP_IS_CALENDAR(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), MRP_TYPE_CALENDAR))
#define MRP_IS_CALENDAR_CLASS(klass)	(G_TYPE_CHECK_TYPE ((obj), MRP_TYPE_CALENDAR))
#define MRP_CALENDAR_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), MRP_TYPE_CALENDAR, MrpCalendarClass))

typedef struct _MrpCalendar         MrpCalendar;
typedef struct _MrpCalendarClass    MrpCalendarClass;
typedef struct _MrpCalendarPriv     MrpCalendarPriv;
typedef struct _MrpCalendarDay      MrpCalendarDay;

struct _MrpCalendar {
	MrpObject         parent;

	MrpCalendarPriv  *priv;
};

struct _MrpCalendarClass {
	MrpObjectClass    parent_class;
};

GType             mrp_calendar_get_type        (void);

MrpCalendar *     mrp_calendar_new             (void);
MrpCalendar *     mrp_calendar_copy            (MrpCalendar      *calendar);
MrpCalendar *     mrp_calendar_derive          (MrpCalendar      *parent);

/* Manipulating */
void              mrp_calendar_set_day         (MrpCalendar      *calendar,
						MrpCalendarDay   *day,
						mrptime           time);
void              mrp_calendar_set_default_day (MrpCalendar      *calendar,
						MrpCalendarDay   *day,
						gint              day_of_week);

/* Querying */
MrpCalendarDay *  mrp_calendar_get_day         (MrpCalendar      *calendar,
						mrptime           time);
MrpCalendarDay *  mrp_calendar_get_default_day (MrpCalendar      *calendar,
						mrptime           time);

MrpCalendarDay *  mrp_calendar_day_new         (void);
MrpCalendarDay *  mrp_calendar_day_ref         (MrpCalendarDay     *day);
void              mrp_calendar_day_unref       (MrpCalendarDay     *day);
GList *           mrp_calendar_get_intervals   (MrpCalendarDay     *day);

#endif /* __MRP_CALENDAR_H__ */
